@@ -152,9 +152,9 @@ gmap <- function (x, exp=1, type='terrain', filename='', ...) {
     p <- p * rad
 	extent(r) <- extent(as.vector(p))
 	projection(r) = "+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y_0=0 +k=1.0 +units=m +nadgrids=@null +wktext  +no_defs"
-	worldFile(r, extension = ".gfw") 
+	try( hdr(r, format='worldfile', extension='.gfw') )
 	ext(filename) <- 'prj'
-	showWKT(projection(r), filename, morphToESRI=TRUE)
+	showWKT(projection(r), file=filename, morphToESRI=TRUE)
     return(r)
 }
 
